@@ -35,7 +35,7 @@ sub new_array
 	} else {
 		return undef;
 	}
-	return Prima::array->new($letter, pack($letter.'*', (0) x $size));
+	return Prima::array->new($letter, pack($letter.'*', (0) x $n));
 }
 
 sub new_empty
@@ -53,36 +53,43 @@ sub new_empty
 sub _debug
 {
 	my $self = shift;
+	my $noprint = shift;
 	my $g = $self->glyphs;
-	print STDERR scalar(@$g), " glyphs: @$g\n";
+
+	my $out = scalar(@$g) . " glyphs: @$g\n";
 	$g = $self->indexes;
-	print STDERR "indexes: ";
+	$out .= "indexes: ";
 	for ( my $i = 0; $i < $#$g; $i++) {
 		my $ix = $g->[$i];
-		print STDERR ( $ix & to::RTL ) ? '-' : '', $ix & ~to::RTL, " ";
+		$out .= (( $ix & to::RTL ) ? '-' : '') . ( $ix & ~to::RTL ) . " ";
 	}
-	print STDERR ": $g->[-1]\n";
+	$out .= ": $g->[-1]\n";
 	if ( $g = $self->advances ) {
-		print STDERR "advances: @$g\n";
+		$out .= "advances: @$g\n";
 		$g = $self->positions;
-		print STDERR "positions: ";
+		$out .= "positions: ";
 		for ( my $i = 0; $i < @$g; $i += 2 ) {
 			my ($x, $y) = @{$g}[$i,$i+1];
-			print STDERR "($x,$y) ";
+			$out .= "($x,$y) ";
 		}
-		print STDERR "\n";
+		$out .= "\n";
 	}
 	if ( $g = $self->fonts ) {
-		print STDERR "fonts: @$g\n";
+		$out .= "fonts: @$g\n";
 		my %f = map { $_ => 1 } @$g;
 		delete $f{0};
 		if ( $::application ) {
 			for my $fid ( sort keys %f ) {
 				my $f = $::application->fontMapperPalette($fid);
-				print STDERR "  #$fid: $f->{name}\n";
+				$out .= "  #$fid: $f->{name}\n";
 			}
 		}
-		print STDERR "\n";
+		$out .= "\n";
+	}
+	if ( $noprint ) {
+		return $out;
+	} else {
+		print STDERR $out;
 	}
 }
 
@@ -422,15 +429,7 @@ sub get_sub
 	my @sub;
 	$sub[GLYPHS]    = Prima::array::substr($glyphs, $from, $length);
 	$sub[INDEXES]   = Prima::array::substr($self->[INDEXES], $from, $length);
-	my $max_index   = 0;
-	my $next_index  = $self->[INDEXES]->[-1]; # next index (or text length) after 
-	for my $ix ( map { $_ & ~to::RTL } @{ $sub[INDEXES] } ) {
-		$max_index = $ix if $max_index < $ix;
-	}
-	for my $ix ( map { $_ & ~to::RTL } @{ $self->[INDEXES] } ) {
-		$next_index = $ix if $ix > $max_index && $ix < $next_index;
-	}
-	push @{$sub[INDEXES]}, $next_index;
+	push @{$sub[INDEXES]}, $self->[INDEXES]->[-1];
 
 	if ( $self-> [ADVANCES] ) {
 		$sub[ADVANCES]  = Prima::array::substr($self->[ADVANCES], $from, $length);
@@ -524,6 +523,7 @@ sub _map2chunks
 	my $selection_map = shift;
 
 	my @chunks;
+	return [] unless @$selection_map;
 	push @chunks, 0 if $selection_map->[0];
 	my $last_selected = -1;
 	for my $selected ( @$selection_map ) {
@@ -600,6 +600,7 @@ sub selection_diff
 	for ( my $i = 0; $i < $max; $i++) {
 		$diff[$i] = (($old->[$i] // 0) == ($new->[$i] // 0) ) ? 0 : 1 ;
 	}
+	pop @diff while @diff and !$diff[-1];
 	return _map2chunks( \@diff );
 }
 
@@ -637,8 +638,8 @@ sub x2cluster
 	my ( $self, $canvas, $width, $from, $length ) = @_;
 	$from //= 0;
 	$length //= -1;
-	my $glyph = $canvas-> text_wrap($self, $width, 
-		tw::ReturnFirstLineLength | tw::BreakSingle, 8, 
+	my $glyph = $canvas-> text_wrap($self, $width,
+		tw::ReturnFirstLineLength | tw::BreakSingle, 8,
 		$from, $length
 	);
 	return $self-> glyph2cluster($glyph);
@@ -677,12 +678,279 @@ sub cursor2offset
 			$len_right + $pos_right :
 			$len_left  + $pos_left;
 	}
-	
+
 	# cursor at the start or at the end
 	return $rtl_right ? $limit : 0 unless defined $pos_left;
 	return $rtl_left ? 0 : $limit;
 }
 
+# poor man's kashida justifier, doesn't use the JSTF table from the font
+sub justify_arabic
+{
+	my ($self, $canvas, $text, $width, %opt) = @_;
+	return unless $text =~ /[\x{600}-\x{6ff}]/s;
+
+	my $glyphs = $self->[GLYPHS];
+	my $length = @$glyphs;
+	return if @$glyphs < 2;
+
+	# find suitable codepoints
+	my $indexes = $self->[INDEXES];
+	my @lengths = $self->index_lengths;
+	my @kashidas;
+	my $l2v     = $self->log2vis;
+
+	reset $text;
+	while ( 1 ) {
+		$text =~ m/\G\s+/gcs and next;
+		$text =~ m/\G$/gcs and last;
+		$text =~ m/\G(\S+)/gcs or return;
+		my $m = $1;
+		next unless $m =~ /[\x{600}-\x{6ff}]/;
+		my ($from, $to) = @$l2v[(pos($text) - length($m), pos($text) - 1)];
+		($to, $from) = ($from, $to) if $from > $to;
+
+		for ( my $i = $from; $i < $to; $i++) {
+			my ( $ix0, $ix1 ) = @$indexes[$i,$i+1];
+
+			# don't justify LTR arabic
+			next unless $ix0 & to::RTL;
+			$ix0 &= ~to::RTL;
+			$i++, next unless $ix1 & to::RTL;
+			$ix1 &= ~to::RTL;
+
+			my $chr = substr($text, $ix0, $lengths[$i]);
+			# all cps marked as LETTER from https://www.unicode.org/charts/PDF/U0600.pdf
+			next if $chr !~ /^[\x{620}-\x{64A}\x{674}-\x{6D3}\x{6D5}\x{6EE}\x{6EF}\x{6FA}-\x{6FC}\x{6FF}]+$/;
+
+			$chr = substr($text, $ix1, $lengths[$i]);
+			$i++, next if $chr !~ /^[\x{620}-\x{64A}\x{674}-\x{6D3}\x{6D5}\x{6EE}\x{6EF}\x{6FA}-\x{6FC}\x{6FF}]+$/;
+			push @kashidas, [
+				scalar(@kashidas), # original index to retain when sorting
+				$ix0,              # codepoint index
+				$i + 1,            # glyph index
+				0                  # number of tatweels inserted
+			];
+			last;
+		}
+	}
+	return unless @kashidas;
+
+	# calculate how many tatweels to insert
+	my $curr_width = $canvas-> get_text_width( $self, to::AddOverhangs );
+	my $expansion  = $width - $curr_width;
+	my $min_width  = delete $opt{min_kashida} // 0;
+	$min_width = 0 if $min_width < 0;
+	return if $expansion <= 0;
+
+	my $k_width;
+	if ( defined $opt{kashida_width}) {
+		$k_width = $opt{kashida_width};
+	} else {
+		my $ins = $canvas-> text_shape( "\x{640}",
+			advances => 1,
+			reorder  => 0,
+			rtl      => 0,
+			level    => ts::Glyphs,
+		) or return 0;
+		$k_width    = $ins->[ADVANCES]->[0];
+	}
+	return unless $k_width;
+
+	my $n_tatweels = int($expansion / $k_width);
+	my @ins_points = sort { $b->[1] <=> $a->[1] } @kashidas;
+	my @tatweel_lengths;
+	my $avg_tatweel = $n_tatweels / @kashidas;
+	my $diff = 0;
+	for ( my $i = 0; $i < @ins_points; $i++) {
+		my $n_tats = int($avg_tatweel + $diff);
+		$n_tats = 0 if $min_width > 0 && $n_tats * $k_width < $min_width;
+		substr($text, $ins_points[$i]->[1], 0, "\x{640}" x $n_tats) if $n_tats > 0;
+		$diff += $avg_tatweel - $n_tats;
+		$kashidas[ $ins_points[$i]->[0] ]->[3] = $n_tats;
+	}
+
+	return wantarray ? ($text, $k_width) : $text if $opt{as_text};
+
+	my $new = $canvas->text_shape($text, %opt);
+	return unless $new;
+
+	$indexes      = $new->[INDEXES];
+	my $advances  = $new->[ADVANCES]  or goto SUCCESS;
+	my $positions = $new->[POSITIONS] or goto SUCCESS;
+
+	# move glyph references after new tatweels
+	my $dg = 0;
+	for my $k (sort { $a->[2] <=> $b->[2] } @kashidas) {
+		$k->[2] += $dg;
+		$dg += $k->[3];
+	}
+
+	$length = @$glyphs;
+	for my $k ( @kashidas ) {
+		my (undef, undef, $at_glyph, $n_tatweels) = @$k;
+
+		# are tatweels rendered as monotonically increased indexes?
+		for (
+			my ($i,$cmp) = ($at_glyph, $indexes->[$at_glyph] & ~to::RTL);
+			$i < $at_glyph + $n_tatweels;
+			$i++, $cmp--
+		) {
+			my $ix = $indexes->[$i];
+			return unless $ix & to::RTL;
+			$ix &= ~to::RTL;
+			return unless $ix == $cmp;
+		}
+
+		# fix clusters
+		my $left_cluster = $indexes->[$at_glyph - 1];
+		my $right_cluster = $indexes->[$at_glyph + $n_tatweels - 1] & ~to::RTL;
+		for ( my $i = $at_glyph; $i < $at_glyph + $n_tatweels; $i++) {
+			$indexes->[$i] = $left_cluster;
+			$advances->[$at_glyph - 1] += $advances->[$i];
+			$positions->[$i * 2] -= $advances->[$i] * ($n_tatweels + $at_glyph - $i);
+			$advances->[$i] = 0;
+		}
+
+		# fix text references
+		$length = @$indexes;
+		for ( my $i = 0; $i < $length; $i++) {
+			my $ix = $indexes->[$i];
+			my $fl = $ix & to::RTL;
+			$ix &= ~to::RTL;
+			next if $ix < $right_cluster;
+			$indexes->[$i] = ($ix - $n_tatweels) | $fl;
+		}
+	}
+
+SUCCESS:
+	@$self = @$new;
+	return wantarray ? (1, $k_width) : 1;
+}
+
+sub justify_interspace
+{
+	my ($self, $canvas, $text, $width, %opt) = @_;
+	my $interletter = $opt{letter} // 1;
+	my $interword   = $opt{word}   // 1;
+	return unless $interletter || $interword;
+
+	my $curr_width  = $canvas->get_text_width($self, to::AddOverhangs);
+	return if $curr_width > $width || $curr_width == 0;
+	my $advances = $self->[ADVANCES] or return 0;
+	my $indexes = $self->[INDEXES];
+	my $n_glyphs = scalar @{$self->[GLYPHS]};
+
+	if ( $opt{as_text} ) {
+		return unless $interword && $width > $curr_width;
+		my $spaces = scalar @{[$text =~ m/\s+/g]} or return;
+		my $space_width;
+		for ( my $i = 0; $i < $n_glyphs; $i++) {
+			my $ix = $indexes->[$i] & ~to::RTL;
+			next unless substr($text, $ix, 1) =~ /\s/;
+			$space_width = $advances->[$i];
+			last;
+		}
+		my $avg_space_incr   = ($width - $curr_width) / ($spaces * $space_width);
+		my $accumulated_incr = 0.0;
+		reset $text;
+		my @insertions;
+		while ( 1 ) {
+			$text =~ m/\G\S+/gcs and next;
+			$text =~ m/\G$/gcs and last;
+			$text =~ m/\G(\s+)/gcs or return;
+			my $dx = int( $avg_space_incr + $accumulated_incr );
+			unshift @insertions, pos($text), $dx;
+			$accumulated_incr += $avg_space_incr - $dx;
+		}
+		for ( my $i = 0; $i < @insertions; $i += 2 ) {
+			substr($text, $insertions[$i], 0, ' ' x $insertions[$i+1]);
+		}
+		return wantarray ? ($text, $space_width) : $text;
+	}
+
+	# (Bringhurst 2008) suggests about 3% expansion or contraction of
+	# intercharacter spacing and about 2% expansion or contraction of
+	# glyphs as the largest permissible deviations -- Wikipedia
+	if ( $interletter) {
+		my $diff  = 1.0 + ($width - $curr_width) / $curr_width;
+		my $max   = $opt{max_interletter} // 1.05;
+		my $dw    = ( $diff > $max ) ? $max : $diff;
+		for ( my $i = 0; $i < $n_glyphs; $i++) {
+			my $xa = $advances->[$i];
+			$curr_width -= $xa;
+			$curr_width += $advances->[$i] = int($xa * $dw);
+		}
+	}
+
+	# the rest goes between words
+	my $spaces = scalar @{[$text =~ m/\s+/g]};
+	if ( $interword && $width > $curr_width && $spaces) {
+		my $avg_space_incr   = ($width - $curr_width) / $spaces;
+		my $accumulated_incr = 0.0;
+		for ( my $i = 0; $i < $n_glyphs; $i++) {
+			my $ix = $indexes->[$i] & ~to::RTL;
+			next unless substr($text, $ix, 1) =~ /\s/;
+
+			my $dx = int( $avg_space_incr + $accumulated_incr );
+			$advances->[$i]   += $dx;
+			$accumulated_incr += $avg_space_incr - $dx;
+		}
+	}
+
+	return 1;
+}
+
+sub justify_tabs
+{
+	my ($self, $canvas, $text, %opt) = @_;
+	return unless $text =~ /\t/s;
+	my $glyphs   = $self->[GLYPHS]   or return;
+	my $indexes  = $self->[INDEXES]  or return;
+	my $advances = $self->[ADVANCES] or return;
+	my $fonts    = $self->[FONTS];
+	my $length   = @$advances;
+	my $ntabs    = $opt{tabs} // 8;
+	my ($space, $width);
+	if ( exists $opt{glyph}) {
+		$space = $opt{glyph};
+		$width = $opt{width};
+	} elsif ( my $s = $canvas->text_shape("\x{20}",
+			advances => 1,
+			reorder  => 0,
+			rtl      => 0,
+			level    => ts::Glyphs,
+		)
+	) {
+		$space = $s->[GLYPHS]->[0];
+		$width = $s->[ADVANCES]->[0];
+	} else {
+		return;
+	}
+	$width *= $ntabs;
+	for ( my $i = 0; $i < $length; $i++) {
+		my $ix = $indexes->[$i] & ~to::RTL;
+		next unless substr($text, $ix, 1) eq "\t";
+		$glyphs->[$i]    = $space;
+		$advances->[$i]  = $width;
+		$fonts->[$i]     = 0 if $fonts;
+	}
+	return wantarray ? ( 1, $space, $width ) : 1;
+}
+
+sub justify
+{
+	my ($self, $canvas, $text, $width, %opt) = @_;
+	my $ok = 0;
+	$ok |= ($self->justify_arabic($canvas, $text, $width, %opt) || 0) if
+		$opt{kashida};
+	$ok |= ($self->justify_interspace($canvas, $text, $width, %opt) || 0) if
+		$opt{letter} || $opt{word};
+	$ok |= ($self->justify_tabs($canvas, $text, %opt) || 0) if
+		exists $opt{tabs};
+	return $ok;
+}
+
 1;
 
 =pod
@@ -1034,6 +1302,122 @@ Read-only accessor to the indexes, see L<Structure> above.
 Returns array where each glyph position is set to a number showing how many characters the
 cluster occupies at this position
 
+=item justify CANVAS, TEXT, WIDTH, %OPTIONS
+
+Umbrella call for C<justify_interspace> if C<$OPTIONS{letter}> or
+C<$OPTIONS{word}> if set; for C<justify_arabic> if C<$OPTIONS{kashida}> is
+set; and for C<justify_tabs> if C<$OPTIONS{tabs}> is set.
+
+Returns a boolean flag whether the glyph object was changed or not.
+
+=item justify_arabic CANVAS, TEXT, WIDTH, %OPTIONS
+
+Performs justifications of arabic TEXT with kashida to the given WIDTH, returns
+either success flag, or new text with explicit I<tatweel> characters inserted.
+
+   my $text = "\x{6a9}\x{634}\x{6cc}\x{62f}\x{647}";
+   my $g = $canvas->text_shape($text) or return;
+   $canvas->text_out($g, 10, 50);
+   $g->justify_arabic($canvas, $text, 200) or return;
+   $canvas->text_out($g, 10, 10);
+
+=for podview <img src="Prima/kashida.gif">
+
+=for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/kashida.gif">
+
+Inserts tatweels only between arabic letters that did not form any ligatures in
+the glyph object, max one tatweel set per word (if any). Does not apply the
+justification if the letters in the word are rendered as LTR due to embedding
+or explcit shaping options; only does justification on RTL letters. If for some
+reason newly inserted tatweels do not form a monotonically increasing series
+after shaping, skips the justifications in that word.
+
+Note: Does not use JSTF font table, on Windows results may be different from native rendering.
+
+Options:
+
+If justification is found to be needed, eventual ligatures with newly inserted
+tatweel glyphs are resolved via a call to C<text_shape(%OPTIONS)> - so any
+needed shaping options, such as C<language>, may be passed there.
+
+=over
+
+=item as_text BOOL = 0
+
+If set, returns new text with inserted tatweels, or undef if no justification
+is possible.
+
+If unset, runs inplace justification on the caller glyph object,
+and returns the boolean success flag.
+
+=item min_kashida INTEGER = 0
+
+Specifies minimal width of a kashida strike to be inserted.
+
+=item kashida_width INTEGER
+
+During the calculation a width of a tatweel glyph is needed - unless supplied
+by this option, it is calculated dynamically. Also, when called in list
+context, and succeeded, returns C< 1, kashida_width > that can be reused in
+subsequent calls.
+
+=back
+
+=item justify_interspace CANVAS, TEXT, WIDTH, %OPTIONS
+
+Performs inplace inter-letter and/or inter-word justifications of TEXT to the
+given WIDTH. Returns either a boolean flag whether there were any change made,
+or, new text with explicit space characters inserted.
+
+Options:
+
+=over
+
+=item as_text BOOL = 0
+
+If set, returns new text with inserted spaces, or undef if no justification is
+possible.
+
+If unset, runs inplace justification on the caller glyph object, and returns
+the boolean success flag.
+
+=item letter BOOL = 1
+
+If set, runs an inter-letter spacing on all glyphs.
+
+=item max_interletter FLOAT = 1.05
+
+When the inter-letter spacing is applied, it is applied first, and can take up
+to C<$OPTIONS{max_interletter} * glyph_width> space.
+
+Inter-word spacing does not have such limit, and in worst case, can produce two
+words moved to the left and to the right edges of the enclosing 0 - WIDTH-1
+rectangle.
+
+=item space_width INTEGER
+
+C<as_text> mode: during the calculation the width of space glyph may be needed
+- unless supplied by C<$OPTIONS{space_width}>, it is calculated dynamically.
+Also, when called in list context, and succeeded, returns C< 1, space_width >
+that can be reused in subsequent calls.
+
+=item word BOOL = 1
+
+If set, runs an inter-word spacing by extending advances on all space glyphs.
+
+=back
+
+=item justify_tabs CANVAS, TEXT, %OPTIONS
+
+Expands tabs as C<$OPTIONS{tabs}> (default:8) spaces.
+
+Needs glyph and the advance of the space glyph to replace the tab glyph.
+If no C<$OPTIONS{glyph}> and C<$OPTIONS{width}> are specified, calculates them.
+
+Returns a boolean flag whether there were any change made. On success, if
+called in the list context, returns also space glyph ID and space glyph width
+for eventual use on the later calls.
+
 =item left_overhang
 
 First integer from the C<overhangs> result.
@@ -1143,6 +1527,10 @@ Returns the length of the text that was shaped and that produced the object.
 Given sub-cluster from C<$FROM> with size C<$LENGTH>, calculates how many
 clusters would fit in width C<$X>.
 
+=item _debug
+
+Dumps glyph object content in a readable format.
+
 =back
 
 =for latex-makedoc cut
