@@ -29,8 +29,7 @@ sub init
 }
 
 my @props = qw(
-	alpha antialias
-	color backColor fillMode fillPattern lineEnd
+	color backColor fillMode fillPattern font lineEnd
 	lineJoin linePattern lineWidth rop rop2 miterLimit
 	textOpaque textOutBaseline 
 );
@@ -48,7 +47,7 @@ for my $prop_name (@props) {
 }
 
 for my $prop_name (qw(
-	arc bar bar_alpha bars chord ellipse fill_chord fill_ellipse
+	alpha arc bar bars chord ellipse fill_chord fill_ellipse
 	fillpoly fill_sector flood_fill line lines polyline
 	put_image_indirect rectangle sector text_out text_shape_out
 )) {
@@ -62,7 +61,7 @@ for my $prop_name (qw(
 }
 
 for my $prop_name (qw(
-	translate set_matrix set_font
+	translate 
 )) {
 	no strict 'refs';
 	*{$prop_name} = sub {
@@ -75,12 +74,6 @@ for my $prop_name (qw(
 	};
 }
 
-sub call
-{
-	my ( $self, @args ) = @_;
-	push @{ $self->{code} }, [ call => @args ];
-}
-
 sub size
 {
 	return @{ $_[0]->{size} } unless $#_;
@@ -130,22 +123,6 @@ sub region
 	return $self->SUPER::region(@_);
 }
 
-sub graphic_context_push
-{
-	my $self = shift;
-	my $ok = $self->SUPER::graphic_context_push;
-	push @{ $self->{code} }, [ 'graphic_context_push' ] if $ok;
-	return $ok;
-}
-
-sub graphic_context_pop
-{
-	my $self = shift;
-	my $ok = $self->SUPER::graphic_context_pop;
-	push @{ $self->{code} }, [ 'graphic_context_pop' ] if $ok;
-	return $ok;
-}
-
 sub width  { $_[0]->{size}->[0] }
 sub height { $_[0]->{size}->[1] }
 
@@ -169,8 +146,6 @@ sub execute
 	my $actual_rgn = $rgn;
 	my @tx   = $canvas-> translate;
 	my @fpo  = $canvas-> fillPatternOffset;
-
-	return unless $canvas->graphic_context_push;
 	$canvas->translate($x + $tx[0], $y + $tx[1]);
 
 	for my $cmd ( @{ $self->{code} } ) {
@@ -183,11 +158,6 @@ sub execute
 			$canvas->$method(@args);
 		} elsif ( $cmd eq 'translate' ) {
 			$canvas->translate($cmd[0] + $tx[0] + $x, $cmd[1] + $tx[1] + $y);
-		} elsif ( $cmd eq 'set_matrix' ) {
-			my @args = @{ $cmd[0] };
-			$canvas->set_matrix([ @args[0..3], $args[4] + $tx[0] + $x, $args[5] + $tx[1] + $y]);
-		} elsif ( $cmd eq 'set_font' ) {
-			$canvas->set_font($cmd[0]);
 		} elsif ( $cmd eq 'clipRect' ) {
 			if ( 4 == grep { $_ == -1 } @cmd ) {
 				$actual_rgn = $rgn;
@@ -206,13 +176,17 @@ sub execute
 		} elsif ( $cmd eq 'fillPatternOffset' ) {
 			$cmd[$_] += $fpo[$_] for 0,1;
 			$canvas-> fillPatternOffset(@cmd);
-		} elsif ( $cmd eq 'call') {
-			my ($sub, @args) = @cmd;
-			$sub->( $self, $canvas, @args );
 		}
 	}
 
-	$canvas->graphic_context_pop;
+	$canvas->$_($save{$_}) for @props;
+	$canvas->fillPatternOffset(@fpo);
+	$canvas->translate(@tx);
+	if ( $rgn ) {
+		$canvas->region($rgn);
+	} else {
+		$canvas->clipRect(@clip);
+	}
 }
 
 1;
@@ -221,11 +195,11 @@ sub execute
 
 =head1 NAME
 
-Prima::Drawable::Metafile - graphics recorder
+Prima::Drawable::Metafile - graphic primitive recorder
 
 =head1 DESCRIPTION
 
-Metafiles can record graphic primitives and replay them later on another canvas
+Metafiles can record graphic primitives and replay them later on another canvas.
 
 =head1 SYNOPSIS
 
@@ -240,11 +214,6 @@ Metafiles can record graphic primitives and replay them later on another canvas
 
 =over
 
-=item call $SUB::($self,$canvas,@ARGS), @ARGS
-
-C<$SUB> will be called when the metafile is executed, with the first two parameters
-the metafile and the target canvas, and C<@ARGS> thereafter.
-
 =item clear
 
 When called without parameters, clears the content before proceeding.
@@ -252,11 +221,11 @@ Otherwise same as C<Drawable.clear>.
 
 =item execute CANVAS,X,Y
 
-Draws the content on the CANVAS with X,Y offset
+Draws the content on a CANVAS with X,Y offset
 
 =item size X,Y
 
-Sets the metafile extensions; the content is not clipped by it.
+Sets metafile extensions; however the content is not clipped by it.
 
 =back
 
