@@ -6,7 +6,6 @@ use warnings;
 use Carp;
 use Cwd;
 
-
 sub new { shift-> create(@_); }     # a shortcut
 
 sub create
@@ -62,12 +61,14 @@ sub read
 	$self-> {fileName} = canonicalize_fname($fname);
 	eval
 	{
-		open FILE, "$fname" or do
+		my $f;
+		open $f, "<", $fname or do
 		{
-			open FILE, ">$fname" or die "Cannot create $fname: $!\n";
-			close FILE;
-			open FILE, "$fname" or die "Cannot open $fname: $!\n";
+			open $f, ">", $fname or die "Cannot create $fname: $!\n";
+			close $f;
+			open $f, "<", $fname or die "Cannot open $fname: $!\n";
 		};
+		binmode $f, ":utf8";
 		my @chunks;
 		my %sectionChunks = ('' => [0]);
 		my %sectionItems = ('' => []);
@@ -77,7 +78,7 @@ sub read
 		my $line = 0;
 		push @chunks, $currentChunk;
 		push @{$sectionItems{''}}, $items;
-		while (<FILE>)
+		while (<$f>)
 		{
 			chomp;
 			if ( /^\s*\[(.*?)\]/)         # new section?
@@ -120,7 +121,7 @@ sub read
 			push( @$currentChunk, $_);
 			$line++;
 		}
-		close FILE;
+		close $f;
 		push( @{$chunks[-1]}, '') if scalar(@{$chunks[-1]}) && $chunks[-1]-> [-1] !~ /^\s*$/;
 		$self-> {chunks} = [@chunks];
 		$self-> {sectionChunks} = {%sectionChunks};
@@ -498,14 +499,16 @@ sub write
 	return unless defined($self-> {fileName}) && $self-> {changed};
 	my $fname = $self-> {fileName};
 	eval {
-		open FILE, ">$fname" or die "Cannot write to the $fname: $!\n";
+		my $f;
+		open $f, ">", $fname or die "Cannot write to the $fname: $!\n";
+		binmode $f, ":utf8";
 		pop @{$self-> {chunks}-> [-1]} if scalar(@{$self-> {chunks}-> [-1]}) && $self-> {chunks}-> [-1]-> [-1] =~ /^\s*$/;
 		for ( @{$self-> {chunks}})
 		{
-			for (@$_) { print FILE "$_\n"; }
+			for (@$_) { print $f "$_\n" }
 		}
 		push( @{$self-> {chunks}-> [-1]}, '') if scalar(@{$self-> {chunks}-> [-1]}) && $self-> {chunks}-> [-1]-> [-1] !~ /^\s*$/;
-		close FILE;
+		close $f;
 	};
 	$self-> {changed} = undef if $@;
 	warn($@) if $@;
@@ -524,7 +527,7 @@ Prima::IniFile - support of Windows-like initialization files
 The module contains a class, that provides mapping of text initialization file to
 a two-level hash structure. The first level
 is called sections, which groups the second level hashes, called items.
-Sections must have unique keys. The items hashes values are arrays of 
+Sections must have unique keys. The items hashes values are arrays of
 text strings. The methods, operated on these arrays are L<get_values>,
 L<set_values>, L<add_values> and L<replace_values>.
 
@@ -581,7 +584,7 @@ Cleans all internal data in the object, including the name of the file.
 =item create PROFILE
 
 Creates an instance of the class. The PROFILE is treated partly as
-an array, partly as a hash. If PROFILE consists of a single item, 
+an array, partly as a hash. If PROFILE consists of a single item,
 the item is treated as a filename. Otherwise, PROFILE is treated as a hash,
 where the following keys are allowed:
 
@@ -604,10 +607,10 @@ with the file data.
 Returns array of values for ITEM in SECTION. If called in scalar context,
 and there is more than one value, the first value in list is returned.
 
-=item items SECTION [ HINTS ] 
+=item items SECTION [ HINTS ]
 
 Returns items in SECTION. HINTS parameters is used to tell if a multiple-valued
-item must be returned as several items of the same name; 
+item must be returned as several items of the same name;
 HINTS can be supplied in the following forms:
 
 items( $section, 1 )
