@@ -2,8 +2,6 @@ package Prima::PS::Glyphs;
 
 use strict;
 use warnings;
-use Carp;
-use Prima;
 use Prima::Utils;
 use base qw(Exporter);
 our @EXPORT = qw(num int32);
@@ -33,7 +31,7 @@ sub get_font
 
 sub int32($)
 {
-	my $n = Prima::Utils::nearest_i( $_[0] );
+	my $n = Prima::Utils::floor( $_[0] + .5 );
 	if (-107 <= $n && $n <= 107) {
 		return chr($n + 139);
 	} elsif (108 <= $n && $n <= 1131) {
