@@ -20,19 +20,19 @@ sub profile_default
 sub init
 {
 	my $self = shift;
-	
+
 	# Create the timer for the motion of the spinner
-	$self->{timer} = $self->insert( Timer => 
+	$self->{timer} = $self->insert( Timer =>
 		name	    => 'Timer',
 		timeout     => 200,
 		delegations => ['Tick'],
 	);
-	
+
 	# Init the Spinner
 	my %profile = $self-> SUPER::init(@_);
 	$self->{start_angle} = 0;
 	$self-> $_($profile{$_}) for qw( value showPercent style active color hiliteColor);
-	
+
 	return %profile;
 }
 
@@ -79,8 +79,8 @@ sub on_paint
 	my ($self,$canvas) = @_;
 
 	$canvas->clear;
-		
-	my $x		 = $self->width/2; 
+
+	my $x		 = $self->width/2;
 	my $y		 = $self->height/2;
 	my $min		 = ( $x < $y ) ? $x : $y;
 	my $scale_factor = $min / 12;
@@ -91,7 +91,7 @@ sub on_paint
 		$canvas->color($color2);
 		$canvas->lineWidth(3*$scale_factor);
 		$canvas->ellipse($x, $y, 17.5*$scale_factor,17.5*$scale_factor);
-		
+
 		$canvas->lineWidth(1.5*$scale_factor);
 		$canvas->color($color1);
 		$canvas->lineEnd(le::Square);
@@ -132,7 +132,7 @@ sub on_paint
 		$canvas->translate($x, $y);
 
 		my @colors = $canvas->new_gradient( palette => [ $self->color, $self->backColor ] )->colors(8+1);
-		my $fill_spline = sub { 
+		my $fill_spline = sub {
 			my ( $n, $p ) = @_;
 			$canvas->color( $colors[( $self->{start_angle} + $n) % 8] );
 			$canvas->fill_spline(_scale($p, $scale_factor, $scale_factor));
@@ -147,25 +147,25 @@ sub on_paint
 		$fill_spline->(1, _h_flip \@petal2);
 		$fill_spline->(0, \@petal1 );
 	} elsif ( $self->{style} eq 'spiral') {
-		my $d1	 = 0.8;
-		my $d2	 = 0.2;
-		my $dx	 = $d2 / 4;
+		my $r = sqrt(2) - 1;
+		my @s = ( 1, 0,    1-.00225, $r,      $r, 0.95+.00225, 0, .95);
+		my @z = ( 0, 1.05, $r+.018, 1.05-.02, 1+.005, $r+.018, 1, 0);
 
-		$canvas->fillWinding(1);
 		$canvas->translate($x, $y);
-		$canvas-> new_path->
-			scale($scale_factor * 22)->
-			rotate(-$self->{start_angle})->
-			arc( 0, 0, $d1 + $dx * 0, $d1 + $dx * 1, 0, 90)->
-			arc( 0, 0, $d1 + $dx * 2, $d1 + $dx * 1, 90, 180)->
-			arc( 0, 0, $d1 + $dx * 2, $d1 + $dx * 3, 180, 270)->
-			arc( 0, 0, $d1 + $dx * 4, $d1 + $dx * 3, 270, 360)->
-			arc( $d1/2, 0, $d2, $d2, 0, 180)->
-			arc( 0, 0, $d1 - $dx * 4, $d1 - $dx * 3, 360, 270)->
-			arc( 0, 0, $d1 - $dx * 2, $d1 - $dx * 3, 270, 180)->
-			arc( 0, 0, $d1 - $dx * 2, $d1 - $dx * 1, 180, 90)->
-			arc( 0, 0, $d1 - $dx * 0, $d1 - $dx * 1, 90, 0)->
-		fill;
+		my $p = $canvas-> new_path->
+			scale($scale_factor * 9)->
+			rotate(-$self->{start_angle});
+		$p->spline(\@s);
+		$p->save;
+			$p->rotate(90)->scale(0.95)->spline(\@s) for 1..3;
+		$p->restore;
+		$p->arc(1.05 ** 4 - 1.20 + 1, 0, .4, .4, 180, 0);
+		$p->save;
+			$p->scale(1.05 ** 4);
+			$p->rotate(-90)->scale(1 / 1.05)->spline(\@z) for 1..3;
+		$p->restore;
+		$p->spline(\@z);
+		$p->fill;
 	}
 }
 
@@ -190,7 +190,7 @@ sub style
 	$self-> repaint;
 }
 
-sub update_value     
+sub update_value
 {
 	my $self = shift;
 	$self->{angle1} = (360 + $self->{start_angle} - $self->{value} * 360 / 100) % 360;
@@ -262,7 +262,7 @@ Prima::Spinner - Show a spinner animation
 
   run Prima;
 
-=for podview <img src="spinner.gif" cut=1>
+=for podview <img src="spinner.gif">
 
 =for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/spinner.gif">
 
