@@ -85,6 +85,7 @@ sub repaint
 	$fader->clear;
 	render_text;
 
+	
 	my ( $dx, $dy ) = (0, 0);
 	my ( $cw, $ch ) = $fader->size;
 	my ( $tw, $th ) = $texter->size;
@@ -99,7 +100,7 @@ sub repaint
 		$dx += $xangle;
 		$dy ++;
 	}
-	$canvas->put_image(0,0,$fader,rop::SrcOver);
+	$canvas->put_image(0,0,$fader,rop::Premultiply);
 
 	$yofs += $ch / 100; 
 	$w->Image->repaint;
@@ -164,4 +165,4 @@ $w->insert( Timer =>
 	timeout => 50,
 	onTick  => \&repaint,
 )->start;
-Prima->run;
+run Prima;
