@@ -12,10 +12,10 @@ extern "C" {
 #define dPUB_ARGS    int rc = recursiveCall
 #define PUB_CHECK    rc = recursiveCall
 
-#define dG_EVAL_ARGS SV * errSave = nil
+#define dG_EVAL_ARGS SV * errSave = NULL
 #define OPEN_G_EVAL \
-errSave = SvTRUE( GvSV( PL_errgv)) ? newSVsv( GvSV( PL_errgv)) : nil;\
-sv_setsv( GvSV( PL_errgv), nilSV)
+errSave = SvTRUE( GvSV( PL_errgv)) ? newSVsv( GvSV( PL_errgv)) : NULL;\
+sv_setsv( GvSV( PL_errgv), NULL_SV)
 #define CLOSE_G_EVAL \
 if ( errSave) sv_catsv( GvSV( PL_errgv), errSave);\
 if ( errSave) sv_free( errSave)
